Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(83)

Unified Diff: content/public/browser/render_view_host.h

Issue 177863007: Replace WebDocument::clearfocusedNode to clearFocusedElement (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebased with latest Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/view_messages.h ('k') | content/renderer/accessibility/renderer_accessibility_complete.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/render_view_host.h
diff --git a/content/public/browser/render_view_host.h b/content/public/browser/render_view_host.h
index 4e40724d74b8d19c0482a873427e0a531534f700..105fb283c4ba65f198f696ef7bf7e446d109553e 100644
--- a/content/public/browser/render_view_host.h
+++ b/content/public/browser/render_view_host.h
@@ -78,8 +78,8 @@ class CONTENT_EXPORT RenderViewHost : virtual public RenderWidgetHost {
// should be a combination of values from BindingsPolicy.
virtual void AllowBindings(int binding_flags) = 0;
- // Tells the renderer to clear the focused node (if any).
- virtual void ClearFocusedNode() = 0;
+ // Tells the renderer to clear the focused element (if any).
+ virtual void ClearFocusedElement() = 0;
// Causes the renderer to close the current page, including running its
// onunload event handler. A ClosePage_ACK message will be sent to the
« no previous file with comments | « content/common/view_messages.h ('k') | content/renderer/accessibility/renderer_accessibility_complete.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698